# INC-{{ACID}}: {{TITLE}}

**Applies to:** {{PREFIX}} project
**Last updated:** {{DATE}}
**Last reviewed:** {{DATE}}
**Status:** Open
**Date:** {{DATE}}
**Severity:** Medium

---

## What Happened

<description>

## Impact

<what was affected>

## Resolution

<how it was resolved>

## Follow-up

- [ ] Action item 1

---

## Change History

| Date | Change | By |
|------|--------|----|
| {{DATE}} | Initial version | — |
